@@ -287,6 +287,7 @@ version: $version
         for my $key (qw/ DBDPG_INITDB PGINITDB /) {
             if (exists $ENV{$key} and length $ENV{$key}) {
                 $initdb = $ENV{$key};
+                ($pg_ctl = $initdb) =~ s/initdb/pg_ctl/;
                 last;
             }
         }
@@ -511,7 +512,7 @@ version: $version
             print {$cfh} "\n\n## DBD::Pg testing parameters\n";
             print {$cfh} "port=$testport\n";
             print {$cfh} "max_connections=11\n";
-            print {$cfh} "log_statement = 'all'\n";
+            print {$cfh} "log_min_duration_statement = 0\n";
             print {$cfh} "log_line_prefix = '%m [%p] '\n";
             print {$cfh} "log_filename = 'postgres%Y-%m-%d.log'\n";
             print {$cfh} "log_rotation_size = 0\n";
@@ -522,7 +523,6 @@ version: $version
             if ($version >= 8.3) {
                 print {$cfh} "logging_collector = on\n";
             }
-            print {$cfh} "log_min_messages = 'DEBUG1'\n";
 
             if ($version >= 9.4) {
                 print {$cfh} "wal_level = logical\n";
